@@ -681,12 +681,24 @@ domGetNodeName(xmlNodePtr node, int xpath_key) {
         rv = xmlStrdup( name );
     }
 
-    if (xpath_key && node->type == XML_ATTRIBUTE_NODE) {
-        // prepend '@'
-        xmlChar* at_key = xmlStrdup( "@" );
-        at_key = xmlStrcat(at_key, rv);
-        xmlFree(rv);
-        rv = at_key;
+    if (xpath_key) {
+        if (node->doc && node->doc->type == XML_HTML_DOCUMENT_NODE) {
+            // convert HTML names to lowercase. make case insensitive
+            int i = prefix == NULL ? 0 : xmlStrlen(prefix);
+
+            for (;rv[i]; i++) {
+                if (rv[i] >= 'A' && rv[i] <= 'Z') {
+                    rv[i] += 'a' - 'A';
+                }
+            }
+        }
+        if (node->type == XML_ATTRIBUTE_NODE) {
+            // prepend '@'
+            xmlChar* at_key = xmlStrdup( "@" );
+            at_key = xmlStrcat(at_key, rv);
+            xmlFree(rv);
+            rv = at_key;
+        }
     } 
 
    return rv;
